import { SelectionRange } from "@codemirror/state";
import { ContentView, ChildCursor, DOMPos } from "./contentview";
import { BlockView } from "./blockview";
import { DecorationSet } from "./decoration";
import { Rect, DOMSelectionState } from "./dom";
import { ViewUpdate, ScrollTarget } from "./extension";
import { EditorView } from "./editorview";
import { Direction } from "./bidi";
export declare class DocView extends ContentView {
    readonly view: EditorView;
    children: BlockView[];
    decorations: readonly DecorationSet[];
    dynamicDecorationMap: boolean[];
    domChanged: {
        newSel: SelectionRange | null;
    } | null;
    hasComposition: {
        from: number;
        to: number;
    } | null;
    markedForComposition: Set<ContentView>;
    lastCompositionAfterCursor: boolean;
    minWidth: number;
    minWidthFrom: number;
    minWidthTo: number;
    impreciseAnchor: DOMPos | null;
    impreciseHead: DOMPos | null;
    forceSelection: boolean;
    dom: HTMLElement;
    lastUpdate: number;
    get length(): number;
    constructor(view: EditorView);
    update(update: ViewUpdate): boolean;
    private updateInner;
    private updateChildren;
    private compositionView;
    private fixCompositionDOM;
    updateSelection(mustRead?: boolean, fromPointer?: boolean): void;
    suppressWidgetCursorChange(sel: DOMSelectionState, cursor: SelectionRange): boolean;
    enforceCursorAssoc(): void;
    moveToLine(pos: DOMPos): DOMPos;
    nearest(dom: Node): ContentView | null;
    posFromDOM(node: Node, offset: number): number;
    domAtPos(pos: number): DOMPos;
    coordsAt(pos: number, side: number): Rect | null;
    coordsForChar(pos: number): DOMRect;
    measureVisibleLineHeights(viewport: {
        from: number;
        to: number;
    }): any[];
    textDirectionAt(pos: number): Direction;
    measureTextSize(): {
        lineHeight: number;
        charWidth: number;
        textHeight: number;
    };
    childCursor(pos?: number): ChildCursor;
    computeBlockGapDeco(): DecorationSet;
    updateDeco(): readonly DecorationSet[];
    scrollIntoView(target: ScrollTarget): boolean;
    split: () => ContentView;
}
export declare function findCompositionNode(view: EditorView, headPos: number): {
    from: number;
    to: number;
    node: Text;
} | null;
