import { EditorSelection, EditorState, SelectionRange, RangeSet, Text } from "@codemirror/state";
import { EditorView } from "./editorview";
import { ViewUpdate, PluginInstance } from "./extension";
export declare class InputState {
    readonly view: EditorView;
    lastKeyCode: number;
    lastKeyTime: number;
    lastTouchTime: number;
    lastFocusTime: number;
    lastScrollTop: number;
    lastScrollLeft: number;
    pendingIOSKey: undefined | {
        key: string;
        keyCode: number;
    } | KeyboardEvent;
    lastSelectionOrigin: string | null;
    lastSelectionTime: number;
    lastEscPress: number;
    lastContextMenu: number;
    scrollHandlers: ((event: Event) => boolean | void)[];
    handlers: {
        [event: string]: {
            observers: readonly HandlerFunction[];
            handlers: readonly HandlerFunction[];
        };
    };
    composing: number;
    compositionFirstChange: boolean | null;
    compositionEndedAt: number;
    compositionPendingKey: boolean;
    compositionPendingChange: boolean;
    mouseSelection: MouseSelection | null;
    draggedContent: SelectionRange | null;
    notifiedFocused: boolean;
    setSelectionOrigin(origin: string): void;
    constructor(view: EditorView);
    handleEvent(event: Event): void;
    runHandlers(type: string, event: Event): void;
    ensureHandlers(plugins: readonly PluginInstance[]): void;
    keydown(event: KeyboardEvent): boolean;
    flushIOSKey(change?: {
        from: number;
        to: number;
        insert: Text;
    }): boolean;
    ignoreDuringComposition(event: Event): boolean;
    startMouseSelection(mouseSelection: MouseSelection): void;
    update(update: ViewUpdate): void;
    destroy(): void;
}
declare type HandlerFunction = (view: EditorView, event: Event) => boolean | void;
export declare const modifierCodes: number[];
export interface MouseSelectionStyle {
    get: (curEvent: MouseEvent, extend: boolean, multiple: boolean) => EditorSelection;
    update: (update: ViewUpdate) => boolean | void;
}
export declare type MakeSelectionStyle = (view: EditorView, event: MouseEvent) => MouseSelectionStyle | null;
declare class MouseSelection {
    private view;
    private startEvent;
    private style;
    private mustSelect;
    dragging: null | boolean;
    extend: boolean;
    multiple: boolean;
    lastEvent: MouseEvent;
    scrollParent: HTMLElement | null;
    scrollSpeed: {
        x: number;
        y: number;
    };
    scrolling: number;
    atoms: readonly RangeSet<any>[];
    constructor(view: EditorView, startEvent: MouseEvent, style: MouseSelectionStyle, mustSelect: boolean);
    start(event: MouseEvent): void;
    move(event: MouseEvent): void;
    up(event: MouseEvent): void;
    destroy(): void;
    setScrollSpeed(sx: number, sy: number): void;
    scroll(): void;
    skipAtoms(sel: EditorSelection): EditorSelection;
    select(event: MouseEvent): void;
    update(update: ViewUpdate): void;
}
export declare const isFocusChange: import("@codemirror/state").AnnotationType<boolean>;
export declare function focusChangeTransaction(state: EditorState, focus: boolean): import("@codemirror/state").Transaction;
export {};
